==> jugg-agile-middleware-nacos-1.1.0-20251124.074426-1-sources.jar: com/jugg/agile/middleware/nacos/discovery/JaNacosDiscoverySpringApplicationRunListener.java <==
package com.jugg.agile.middleware.nacos.discovery;

import com.alibaba.cloud.nacos.NacosDiscoveryProperties;
import com.jugg.agile.framework.core.util.reflect.clazz.JaClassUtil;
import com.jugg.agile.spring.boot.util.JaSpringBootUtil;
import com.jugg.agile.spring.util.JaSpringBeanUtil;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.SpringApplicationRunListener;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.core.Ordered;
import org.springframework.core.env.ConfigurableEnvironment;

public class JaNacosDiscoverySpringApplicationRunListener implements SpringApplicationRunListener, Ordered {

    public JaNacosDiscoverySpringApplicationRunListener(SpringApplication springApplication, String[] args) {
    }

    public void starting() {
    }

    public void environmentPrepared(ConfigurableEnvironment environment) {
    }

    @Override
    public void contextPrepared(ConfigurableApplicationContext context) {

    }

    @Override
    public void contextLoaded(ConfigurableApplicationContext context) {

    }

    @Override
    public void started(ConfigurableApplicationContext context) {
        if (!JaSpringBootUtil.isCloudContainer()) {
            if (JaClassUtil.hashClass("com.alibaba.nacos.api.naming.NamingService")) {
                JaNamingService.setNamingService(JaNamingService.getNamingServiceByNacosServiceManager());
                JaNacosDiscoveryPropertiesProcessor.setNacosDiscoveryProperties(JaSpringBeanUtil.getBean(NacosDiscoveryProperties.class));
                JaNamingService.registerInstancesByCurrentInstance();
//                JaNamingService.deregisterCurrentInstance();
            }
        }
    }

    @Override
    public void running(ConfigurableApplicationContext context) {
        if (!JaSpringBootUtil.isCloudContainer()) {
        }
    }

    @Override
    public void failed(ConfigurableApplicationContext context, Throwable exception) {
    }


    @Override
    public int getOrder() {
        return -5;
    }
}

==> jugg-agile-middleware-nacos-3.5.3.0-20251202.132200-2-sources.jar: com/jugg/agile/middleware/nacos/discovery/JaNacosDiscoverySpringApplicationRunListener.java <==
package com.jugg.agile.middleware.nacos.discovery;

import com.alibaba.cloud.nacos.NacosDiscoveryProperties;
import com.jugg.agile.framework.core.util.reflect.clazz.JaClassUtil;
import com.jugg.agile.spring.boot.util.JaSpringBootUtil;
import com.jugg.agile.spring.util.JaSpringBeanUtil;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.SpringApplicationRunListener;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.core.Ordered;
import org.springframework.core.env.ConfigurableEnvironment;

import java.time.Duration;

public class JaNacosDiscoverySpringApplicationRunListener implements SpringApplicationRunListener, Ordered {

    public JaNacosDiscoverySpringApplicationRunListener(SpringApplication springApplication, String[] args) {
    }

    public void starting() {
    }

    public void environmentPrepared(ConfigurableEnvironment environment) {
    }

    @Override
    public void contextPrepared(ConfigurableApplicationContext context) {

    }

    @Override
    public void contextLoaded(ConfigurableApplicationContext context) {

    }

    @Override
    public void started(ConfigurableApplicationContext context, Duration timeTaken) {
        if (!JaSpringBootUtil.isCloudContainer()) {
            if (JaClassUtil.hashClass("com.alibaba.nacos.api.naming.NamingService")) {
                JaNamingService.setNamingService(JaNamingService.getNamingServiceByNacosServiceManager());
                JaNacosDiscoveryPropertiesProcessor.setNacosDiscoveryProperties(JaSpringBeanUtil.getBean(NacosDiscoveryProperties.class));
                JaNamingService.registerInstancesByCurrentInstance();
//                JaNamingService.deregisterCurrentInstance();
            }
        }
    }

    @Override
    public void failed(ConfigurableApplicationContext context, Throwable exception) {
    }


    @Override
    public int getOrder() {
        return -5;
    }
}
